# Changelog

## verison 1.0.5

- lowered version for required dependencies

- exclude airflow dep's from install

## verison 1.0.4

- update config.json folder from AIRFLOW_HOME env

## verison 1.0.3

- update documentation info in pip package

## verison 1.0.2

- add package dependencies

## verison 1.0.1

- remove unused files

## version 1.0.0

- initial commit

- work with Qlik Sense, QlikView and NPrinting tasks